pub trait Bcd<T>: Sized {
// Required methods
fn from_bcd(value: T) -> Self;
fn into_bcd(self) -> T;
}Expand description
BCD (Binary-Coded Decimal) is a class of binary encodings of decimal numbers where each decimal digit is represented by a fixed number of bits.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".